Possible improvements
=====================

* improve docstrings
* add typing annotations
* improve the mosaicking algorithm
* improve documentation
* corrections (and coordinates) interpolation (bi-linear),
  notebook already available.
* replace returned dictionaries (with 'x', 'y', 'units', etc. keys)
  with named tuples (TBD)
* allow the user to select correction to export into the KMZ
